(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     52861,       1098]
NotebookOptionsPosition[     51106,       1066]
NotebookOutlinePosition[     51589,       1083]
CellTagsIndexPosition[     51546,       1080]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Clear all symbols from previous evaluations to avoid problems\
\>", "Text",
 CellChangeTimes->{{3.4989844474375*^9, 3.4989844766875*^9}, {3.498986081*^9, 
  3.498986101765625*^9}, {3.499013121265625*^9, 
  3.499013127203125*^9}},ExpressionUUID->"09352dc8-3374-4919-9ad3-\
bb9e0f6dc757"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.498986015390625*^9, 3.4989860174375*^9}, 
   3.49898606721875*^9},ExpressionUUID->"b34912b4-662f-4368-b306-\
2abe0c3985e9"],

Cell[CellGroupData[{

Cell["Percolation - square lattice", "Section",
 CellChangeTimes->{{3.498984417765625*^9, 3.498984422953125*^9}, 
   3.499011424390625*^9, {3.5023835785282984`*^9, 3.5023835813207035`*^9}, 
   3.5023840423015127`*^9, {3.50262521559375*^9, 3.5026252365*^9}, {
   3.843114026514204*^9, 3.8431140342736473`*^9}, {3.843558381683334*^9, 
   3.8435583965544553`*^9}, 3.846048606239182*^9, {3.8463162427093067`*^9, 
   3.846316251978837*^9}},ExpressionUUID->"9c44156e-68a8-492f-9a16-\
76a98c8aa6ef"],

Cell["\<\
Hoshen-Kopelman algorithm for the square lattice, it returns a 2d array with \
all sites belonging to a cluster labelled by the same number\
\>", "Text",
 CellChangeTimes->{{3.49898467159375*^9, 3.498984682234375*^9}, {
   3.498984755890625*^9, 3.498984759109375*^9}, {3.498985180640625*^9, 
   3.49898518103125*^9}, {3.49901261171875*^9, 3.49901266921875*^9}, {
   3.502626619875*^9, 3.5026266385*^9}, {3.50262710609375*^9, 
   3.50262722209375*^9}, 3.8292991124277744`*^9, {3.8431141315452113`*^9, 
   3.8431145249967155`*^9}, {3.8435706295421405`*^9, 
   3.8435706826271734`*^9}, {3.843667765754773*^9, 3.843667767187603*^9}, {
   3.8460489717730894`*^9, 3.8460490109643307`*^9}, {3.8463162604513216`*^9, 
   3.846316287961895*^9}, {3.846685151015071*^9, 3.846685247437586*^9}, {
   3.84668609353498*^9, 3.8466860948870573`*^9}, 
   3.8788357144455333`*^9},ExpressionUUID->"b779bbf7-cc84-460c-a7a6-\
bfc985e7489c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"HoshenKopelmanSquareLattice", "[", "lattice_", "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "labelledLattice", ",", "n", ",", "m", ",", "lastLabel", ",", 
       "leftLabel", ",", "labelAssignments", ",", "newLabels"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", "m"}], "}"}], "=", 
       RowBox[{"Dimensions", "[", "lattice", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"labelledLattice", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "m"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"labelAssignments", "=", 
       RowBox[{"Array", "[", 
        RowBox[{
         RowBox[{"#", "&"}], ",", 
         RowBox[{"Ceiling", "[", 
          RowBox[{"n", "*", 
           RowBox[{"m", "/", "2"}]}], "]"}]}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"maximum", " ", "number", " ", "of", " ", "clusters"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"lastLabel", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "loop", " ", "over", " ", "the", " ", "lattice", " ", "row", " ", 
         "by", " ", "row"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"lattice", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "\[Equal]", 
           "1"}], ",", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
             "if", " ", "site", " ", "is", " ", "occupied", " ", "then"}], 
             " ", "..."}], " ", 
            RowBox[{"(", 
             RowBox[{"otherwise", " ", "move", " ", "on"}], ")"}]}], " ", 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"lastLabel", "\[Equal]", "0"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{
              "if", " ", "this", " ", "is", " ", "the", " ", "first", " ", 
               "cluster"}], ",", " ", 
              RowBox[{"assign", " ", "1"}]}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "=", "1"}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"lastLabel", "=", "1"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", "otherwise", " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"i", "==", "1"}], ",", "\[IndentingNewLine]", 
               RowBox[{"(*", " ", 
                RowBox[{
                 RowBox[{
                 "if", " ", "we", " ", "are", " ", "in", " ", "the", " ", 
                  "first", " ", "row"}], ",", " ", 
                 RowBox[{
                 "just", " ", "copy", " ", "the", " ", "left", " ", 
                  "neighbour", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"if", " ", "unoccupied"}], ",", " ", 
                    RowBox[{
                    "it", " ", "will", " ", "be", " ", "later", " ", 
                    "corrected"}]}], ")"}]}]}], " ", "*)"}], 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "=", 
                RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", 
                  RowBox[{"j", "-", "1"}]}], "\[RightDoubleBracket]"}]}], ",",
                "\[IndentingNewLine]", 
               RowBox[{"(*", " ", 
                RowBox[{
                "otherwise", " ", "copy", " ", "first", " ", "the", " ", 
                 "label", " ", "of", " ", "the", " ", "neighbour", " ", 
                 "above", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"if", " ", "unoccupied"}], ",", " ", 
                   RowBox[{
                   "it", " ", "will", " ", "be", " ", "later", " ", 
                    "corrected"}]}], ")"}]}], " ", "*)"}], 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"i", "-", "1"}], ",", "j"}], 
                    "\[RightDoubleBracket]"}], ">", "0"}], ",", 
                  RowBox[{
                   RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "=", 
                   RowBox[{"labelAssignments", "\[LeftDoubleBracket]", 
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"i", "-", "1"}], ",", "j"}], 
                    "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}]}]}], 
                 "]"}], ";", "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{
                 "and", " ", "then", " ", "for", " ", "all", " ", "columns", 
                  " ", "but", " ", "the", " ", "first"}], " ", "*)"}], 
                "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"j", ">", "1"}], ",", "\[IndentingNewLine]", 
                  RowBox[{"(*", " ", 
                   RowBox[{
                   "check", " ", "the", " ", "left", " ", "neighbour", " ", 
                    "and", " ", "possibly", " ", "resolve", " ", "conflict"}],
                    " ", "*)"}], "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", 
                    RowBox[{"j", "-", "1"}]}], "\[RightDoubleBracket]"}], ">",
                     "0"}], ",", " ", "\[IndentingNewLine]", 
                    RowBox[{"(*", " ", 
                    RowBox[{
                    RowBox[{
                    "if", " ", "the", " ", "left", " ", "site", " ", "is", 
                    " ", "occupied"}], " ", "..."}], " ", "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"leftLabel", "=", 
                    RowBox[{"labelAssignments", "\[LeftDoubleBracket]", 
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", 
                    RowBox[{"j", "-", "1"}]}], "\[RightDoubleBracket]"}], 
                    "\[RightDoubleBracket]"}]}], ";", " ", 
                    RowBox[{"(*", " ", 
                    RowBox[{
                    "just", " ", "to", " ", "simplify", " ", "things"}], " ", 
                    "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"If", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"leftLabel", "<", 
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}], ",",
                     "\[IndentingNewLine]", 
                    RowBox[{"(*", " ", 
                    RowBox[{
                    RowBox[{
                    "if", " ", "the", " ", "cluster", " ", "to", " ", "the", 
                    " ", "left", " ", "has", " ", "a", " ", "smaller", " ", 
                    "label", " ", "then", " ", "the", " ", "one", " ", 
                    "above"}], ",", " ", "\[IndentingNewLine]", "   ", 
                    RowBox[{
                    "resolve", " ", "conflict", " ", "and", " ", "replace", 
                    " ", "all", " ", "necessary", " ", "labels"}]}], " ", 
                    "*)"}], "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"labelAssignments", "=", 
                    RowBox[{"ReplaceAll", "[", 
                    RowBox[{"labelAssignments", ",", 
                    RowBox[{
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], 
                    "\[Rule]", "leftLabel"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "=", 
                    "leftLabel"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", " ", "else", " ", "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"leftLabel", ">", 
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}], " ",
                     "&&", 
                    RowBox[{
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], ">", 
                    "0"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", " ", 
                    RowBox[{
                    RowBox[{
                    "if", " ", "the", " ", "cluster", " ", "to", " ", "the", 
                    " ", "left", " ", "has", " ", "a", " ", "larger", " ", 
                    "label", " ", "then", " ", "the", " ", "one", " ", 
                    "above"}], ",", " ", "\[IndentingNewLine]", "   ", 
                    RowBox[{
                    "resolve", " ", "conflict", " ", "the", " ", "other", " ",
                     "way", " ", "and", " ", "replace", " ", "all", " ", 
                    "necessary", " ", "labels"}]}], " ", "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"labelAssignments", "=", 
                    RowBox[{"ReplaceAll", "[", 
                    RowBox[{"labelAssignments", ",", 
                    RowBox[{"leftLabel", "->", 
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                    "]"}]}], ",", " ", "\[IndentingNewLine]", 
                    RowBox[{"(*", " ", 
                    RowBox[{
                    "otherwise", " ", "just", " ", "copy", " ", "the", " ", 
                    "left", " ", "label"}], " ", "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "=", 
                    "leftLabel"}]}], "\[IndentingNewLine]", "]"}]}], 
                    "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
                   "]"}]}], " ", 
                 RowBox[{"(*", " ", 
                  RowBox[{
                  "if", " ", "the", " ", "left", " ", "site", " ", "is", " ", 
                   "occupied"}], " ", "*)"}], "\[IndentingNewLine]", 
                 "]"}]}]}], 
              RowBox[{"(*", " ", 
               RowBox[{
               "if", " ", "we", " ", "are", " ", "not", " ", "in", " ", "the",
                 " ", "first", " ", "column"}], " ", "*)"}], 
              "\[IndentingNewLine]", "]"}], ";", 
             RowBox[{"(*", " ", 
              RowBox[{
              "if", " ", "we", " ", "are", " ", "in", " ", "the", " ", 
               "first", " ", "row"}], " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"If", "[", " ", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], 
                "\[Equal]", "0"}], ",", "\[IndentingNewLine]", 
               RowBox[{"(*", " ", 
                RowBox[{
                "if", " ", "the", " ", "label", " ", "was", " ", "not", " ", 
                 "determined", " ", "from", " ", "neighbours", " ", "then", 
                 " ", "assign", " ", "a", " ", "new", " ", "label"}], " ", 
                "*)"}], "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"lastLabel", "++"}], ";", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                  RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "=", 
                 "lastLabel"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
           "\[IndentingNewLine]", "]"}]}], 
         RowBox[{"(*", " ", 
          RowBox[{
          "if", " ", "it", " ", "is", " ", "the", " ", "first", " ", 
           "cluster"}], " ", "*)"}], "\[IndentingNewLine]", "]"}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{"if", " ", "site", " ", "is", " ", "occupied"}], " ", "*)"}],
         "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "m"}], "}"}]}], "\[IndentingNewLine]", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", "relabelling", " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"newLabels", "=", 
       RowBox[{"Array", "[", 
        RowBox[{
         RowBox[{"#", "&"}], ",", 
         RowBox[{"Ceiling", "[", 
          RowBox[{"n", "*", 
           RowBox[{"m", "/", "2"}]}], "]"}]}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"maximum", " ", "number", " ", "of", " ", "clusters"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"lastLabel", "=", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], ">", "0"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
             RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "=", 
            RowBox[{"labelAssignments", "\[LeftDoubleBracket]", 
             RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], 
             "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"newLabels", "\[LeftDoubleBracket]", 
               RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], 
               "\[RightDoubleBracket]"}], ">", "lastLabel"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"lastLabel", "++"}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"newLabels", "\[LeftDoubleBracket]", 
                RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], 
                "\[RightDoubleBracket]"}], "=", "lastLabel"}]}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
             RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "=", 
            RowBox[{"newLabels", "\[LeftDoubleBracket]", 
             RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], 
             "\[RightDoubleBracket]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "m"}], "}"}]}], "\[IndentingNewLine]", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", "labelledLattice", "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzWtMkwcYBeCKwqyrWChBG1CogyiCphLRGF0vc3JpRJtiN1FmsdzxglVA
qlizsoJDOoVhsd1cK3KLQQZduYxAhxugoxIBoysyirbGEK2gKKWgS/ad78eb
588552VJc0RpHhQK5SvioLBjLCimwckv0OWHQEH3xXdwja2JFkvIduYGwkBR
cQhcUHuGwRfbnBvhCUleJIz1WcqDLn/Jbsga08fBX1dtFcLSo0wRfEQzSGB0
88EseCRYJ4fJaYkKSLuSch9mhMoGoVc9/SGsvPPsXzJX0fcMbv3pLamS73gF
vTv9p6Fwx9ndcYR+i0r2QvZvdDFcnyQ/Ab/cpciD14rbFLBpdagKKo4dL4cc
68BN+MO+W3VQ89lcI2ztH78Nv6ucbYG9j8UmuCeL2QnDrOGklHgnY4Cw5NA8
KefuvBQa/3Cnw1yd6ST8olp8GhpG5HQL4Ubq65Vw4MOrYMgs6oiCCmoiFwqo
KTzoERAVDfsPGwRwLX+JCGYXmPfDVP32g3C5h4h0svylBLZvKcyB1NJtudAq
416AUr/hIsiy9qngzI8lpdBeSy2DQ/EmPbw5v9kA28x+rXCf5F4PuWtf7oZL
oiLp9wmrDYOhMMS3KgK+aRraDI1PFkfC0BWqFHjS+Ndp+FLVoIRnlDu0cNnZ
YQPUHdfVQK+Pk7dgzuPfm2H+p33tsJDR1Q3bvRbuwOJLix5ApfxzO9SMKEkb
U5NcsFegJq28HOk7iJ0/0wNg13XNiIvQU7ZzFEYL9Q74JnzsOZSaaI/mCG38
VaRHcjSjsPu8bgIaPmgnoYa18i2sqetww68ZTz3dhFPyJ3QYHm70gXspAf5Q
lThLyvNlhsEiXQrpGY59E+R497Hh8KDaCCOmW0nZphtpMS+c/OktQZnQv4mZ
B+/xTpXD2Pw2LVyr9TbApR/3N8OshMvt0NJy0QytB6p7YeOh0b/Jfm2wBa4P
qhiGqXUTD6GH4NwoZG+afQo7zYwpKAw8RY0ljPMsD4LvW9Tb4fOC61wYyGfE
wJ0BigTYY+n6BpZVzKRDSkRSBuwc5xyFDTbxMSi12GVwRF2fD11zV8/DBKfs
e3ihUKmBunU0Pax611ALux3iOvjztx1muKYsqYf802rvhSLbAmm2459xaNMc
noAFVb+8h5lTr11ww9AnPnGE/bZZPziUzOVC7/q7POj+z7UHiliMeJitnUmG
hZe6pFCwy5EBayaiM+H/dnn7BQ==
  "],
 CellLabel->"In[1]:=",ExpressionUUID->"b9fad58f-0cc3-4473-9260-59bcf8d45ece"],

Cell["\<\
Function taking the result of the Hoshen-Kopelman algorithm for the square \
lattice and returning an array with the sizes of clusters\
\>", "Text",
 CellChangeTimes->{{3.49898467159375*^9, 3.498984682234375*^9}, {
   3.498984755890625*^9, 3.498984759109375*^9}, {3.498985180640625*^9, 
   3.49898518103125*^9}, {3.49901261171875*^9, 3.49901266921875*^9}, {
   3.502626619875*^9, 3.5026266385*^9}, {3.50262710609375*^9, 
   3.50262722209375*^9}, 3.8292991124277744`*^9, {3.8431141315452113`*^9, 
   3.8431145249967155`*^9}, {3.8435706295421405`*^9, 
   3.8435706826271734`*^9}, {3.843667765754773*^9, 3.843667767187603*^9}, {
   3.8460489717730894`*^9, 3.8460490109643307`*^9}, {3.8463162604513216`*^9, 
   3.846316287961895*^9}, {3.846685151015071*^9, 3.8466853283732147`*^9}, {
   3.8466861084148307`*^9, 
   3.846686109430889*^9}},ExpressionUUID->"0fff6592-5b78-4c23-86c5-\
693acd583b81"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SizesOfClustersSquareLattice", "[", "labelledLattice_", "]"}], ":=",
    "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "n", ",", "m", ",", "lastLabel", ",", "nclusters", ",", 
       "clusterSizes"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", "m"}], "}"}], "=", 
       RowBox[{"Dimensions", "[", "labelledLattice", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"clusterSizes", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"Max", "[", "labelledLattice", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "loop", " ", "over", " ", "the", " ", "lattice", " ", "row", " ", 
         "by", " ", "row"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], ">", "0"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"clusterSizes", "\[LeftDoubleBracket]", 
             RowBox[{"labelledLattice", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], 
             "\[RightDoubleBracket]"}], "++"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "m"}], "}"}]}], "\[IndentingNewLine]", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", "clusterSizes", "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzH8slAEAxvEjrKuj82O4qFy5Lbs0bmFNHVcRt3C7ZY2syx2aimPOjzNd
2+loSqXsytva3ZDMJF3nR4ZSTk0sNHYo5bRmXEUNh/7ofd4/nn3+efZlS+Xi
dHsajRZODoo6p/ecbLQKiogCfyjsuf4X7p5pYcSQBlkVvtBXXOYPNyodA+CP
MGsgzJbk82CM69ZIuOopiYLsaV0sfOYdKoIVl1hiOM7QS2B0a3ImTPUjlPB8
epIKMu7IhuAFTu4wdHrC/ASr+2Y/U7+7plkY+nCZUi2YW4QuXZ6/oSi8OCqW
1MOuPB4GvWAmwv0pymx44rgqHz4oa1fBll0cDVRdzqqCfPNgHbyV0NQAtfvW
mmHbwJen8Fr1ynPYP5FohKcyWV0wwMylpMVZ3QdJy8+uU/LfrUuh4ZUtAyoI
Yw48VpuYB/VjSuYH0kD6Ty84uLnoB1mlnSFQRU+KgEK6LBLa+4REw4FzeiHc
K3AQw4tFvadhmu5wMnS2F1POVy1IYMehEjmkV4QpoDk34iqUeoyWQrbZpIF/
7pVXQMtj+k04EmfUwbr1YD1s7/VogwmS96+prsXZBh1CeMwh0lr9MAf6u90/
AJdaRoKhYWoLD3J2aGQwx/A2Dy5oGtWwUB1eA7cVj+ohkUXUQ6d/801QPvGy
FRZsN3XAEvfuHtjhtNEHy27YfYRq5VEL1I6pKZvTUlZhv7CSsvo2z20YnTcZ
PrD7kXZsldQx98gkjBbp5uASd/o7lBoZ42ukMwJvylS5dhL2XCG+Qv1mzTzU
sr2WYX1Dpw2ecf/maCP9pZxiQi7X4ArjaT6eUJO0QhnpxgqApYSMspBvOQj5
LqYg2L+zTQzbZRIF/A/z4Qe2
  "],
 CellLabel->"In[2]:=",ExpressionUUID->"a8a5d70e-c070-42dd-a69f-da97f512ea31"],

Cell["\<\
Example of square lattices 10 x 10 for various probabilities p\
\>", "Text",
 CellChangeTimes->{{3.8788314907238293`*^9, 
  3.878831518216672*^9}},ExpressionUUID->"50560771-1f87-43ae-9abb-\
b0020376c1ac"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "m"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{"10", ",", "10"}], "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"lattice", " ", "size"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"np", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lattice", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", "np"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"clusters", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", "np"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"probabilities", "=", 
   RowBox[{"0.0", "+", 
    RowBox[{"0.2", 
     RowBox[{"Range", "[", "np", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "lattice", "\[LeftDoubleBracket]", "ip", "\[RightDoubleBracket]"}], "=", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RandomReal", "[", "]"}], "<=", 
            RowBox[{
            "probabilities", "\[LeftDoubleBracket]", "ip", 
             "\[RightDoubleBracket]"}]}], ",", "1", ",", "0"}], "]"}], "&"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "m"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
      "clusters", "\[LeftDoubleBracket]", "ip", "\[RightDoubleBracket]"}], 
      "=", 
      RowBox[{"HoshenKopelmanSquareLattice", "[", 
       RowBox[{
       "lattice", "\[LeftDoubleBracket]", "ip", "\[RightDoubleBracket]"}], 
       "]"}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"ip", ",", "1", ",", "np"}], "}"}]}], "\[IndentingNewLine]", 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
        "lattice", "\[LeftDoubleBracket]", "ip", "\[RightDoubleBracket]"}], 
        ",", 
        RowBox[{"ColorRules", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "\[Rule]", "Black"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "\[Rule]", "White"}]}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<p = \>\"", ",", 
            RowBox[{
            "probabilities", "\[LeftDoubleBracket]", "ip", 
             "\[RightDoubleBracket]"}]}], "}"}], "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ip", ",", "1", ",", "np"}], "}"}]}], "]"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Hoshen-Kopelman labbeling:\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"MatrixForm", "[", 
    RowBox[{
    "clusters", "\[LeftDoubleBracket]", "ip", "\[RightDoubleBracket]"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"ip", ",", "1", ",", "np"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Sizes of clusters:\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"SizesOfClustersSquareLattice", "[", 
    RowBox[{
    "clusters", "\[LeftDoubleBracket]", "ip", "\[RightDoubleBracket]"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"ip", ",", "1", ",", "np"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8435709290096273`*^9, 3.8435709713071117`*^9}, {
   3.8436388890066733`*^9, 3.8436389892044044`*^9}, {3.843641904643158*^9, 
   3.8436419054022017`*^9}, {3.843643337484112*^9, 3.843643337940138*^9}, {
   3.843643389930112*^9, 3.843643628605763*^9}, {3.8436438696975527`*^9, 
   3.8436439054495974`*^9}, {3.843643937887453*^9, 3.8436440915592422`*^9}, {
   3.843644177871179*^9, 3.8436442076698837`*^9}, {3.843644318136202*^9, 
   3.843644352605173*^9}, {3.8436624774272337`*^9, 3.8436624910615416`*^9}, 
   3.8436625254368124`*^9, {3.8436625655279903`*^9, 3.843662574606933*^9}, {
   3.843662706339613*^9, 3.8436629118020935`*^9}, {3.8436630936338964`*^9, 
   3.843663101405065*^9}, {3.843663177363185*^9, 3.84366330091958*^9}, {
   3.843664785543929*^9, 3.8436648061096206`*^9}, {3.8436648418721633`*^9, 
   3.8436650837494946`*^9}, {3.8436651774546027`*^9, 3.843665196200303*^9}, {
   3.8436652278684444`*^9, 3.8436653122236395`*^9}, {3.843665356664573*^9, 
   3.8436654022164526`*^9}, {3.8436654597484245`*^9, 
   3.8436654605317073`*^9}, {3.8436655091905556`*^9, 
   3.8436655223563557`*^9}, {3.843665568909583*^9, 3.8436656040302052`*^9}, {
   3.8436656709965534`*^9, 3.8436656891470776`*^9}, {3.8436657280497875`*^9, 
   3.8436657285956044`*^9}, 3.8436657825047855`*^9, {3.8436658265720563`*^9, 
   3.843665827639544*^9}, {3.8436658593890595`*^9, 3.8436658657721233`*^9}, {
   3.8436659217216434`*^9, 3.84366594389198*^9}, {3.8436661115085325`*^9, 
   3.8436661230465107`*^9}, {3.8436663324723315`*^9, 3.843666346460675*^9}, {
   3.8436663771921005`*^9, 3.843666382559655*^9}, {3.8436664642746043`*^9, 
   3.8436664974142113`*^9}, {3.8436665277573414`*^9, 
   3.8436665710785933`*^9}, {3.843666659726678*^9, 3.8436666848127537`*^9}, 
   3.8436667179479427`*^9, {3.8436667733167257`*^9, 3.8436668078444967`*^9}, {
   3.843666895412548*^9, 3.8436669160562563`*^9}, {3.8436669522426643`*^9, 
   3.843666978284191*^9}, {3.8436673494105735`*^9, 3.843667367901639*^9}, {
   3.843667483013933*^9, 3.843667490129805*^9}, {3.8436676017888436`*^9, 
   3.8436677241836863`*^9}, {3.8436732357880707`*^9, 
   3.8436732575761943`*^9}, {3.8436733096052322`*^9, 
   3.8436733762866163`*^9}, {3.8436737843796787`*^9, 
   3.8436738215632772`*^9}, {3.843673857008175*^9, 3.843673911942176*^9}, {
   3.843673945648649*^9, 3.8436739724881067`*^9}, {3.8436740501045265`*^9, 
   3.8436740506370726`*^9}, {3.8436744193568325`*^9, 3.843674420951388*^9}, 
   3.843674457543649*^9, {3.8436755359258842`*^9, 3.843675680925063*^9}, {
   3.843675711980811*^9, 3.843675728104393*^9}, {3.843675822518078*^9, 
   3.8436758275330586`*^9}, {3.843675873293178*^9, 3.843675874153902*^9}, {
   3.8436759079791117`*^9, 3.8436759090697794`*^9}, 3.843675970183335*^9, {
   3.8436761640287695`*^9, 3.843676169231389*^9}, {3.843709815534439*^9, 
   3.8437098227978544`*^9}, {3.843709952501273*^9, 3.8437099526922836`*^9}, 
   3.843711015679083*^9, {3.843711114492735*^9, 3.843711136628001*^9}, {
   3.8437113032085285`*^9, 3.843711318288391*^9}, {3.8437231597906866`*^9, 
   3.8437233039559326`*^9}, {3.843723374827986*^9, 3.843723527713731*^9}, {
   3.8437235778585987`*^9, 3.843723590681332*^9}, {3.843723627320428*^9, 
   3.8437236625044403`*^9}, {3.8437236963203745`*^9, 3.843723723783945*^9}, {
   3.843723762086136*^9, 3.84372379258288*^9}, {3.8437239136998076`*^9, 
   3.843723924092402*^9}, {3.843723959708439*^9, 3.843724003003916*^9}, {
   3.843724038906969*^9, 3.84372421218388*^9}, {3.843724257919496*^9, 
   3.843724369243863*^9}, {3.843724401499708*^9, 3.843724469660607*^9}, {
   3.8437245997330465`*^9, 3.8437246161159835`*^9}, {3.843725214991237*^9, 
   3.8437253834528728`*^9}, {3.843802126409319*^9, 3.843802241224886*^9}, {
   3.843802353946333*^9, 3.8438024063583307`*^9}, 3.846044367094717*^9, {
   3.8460445260818105`*^9, 3.8460445277819076`*^9}, 3.846045405291098*^9, {
   3.8460472104493475`*^9, 3.8460472664725513`*^9}, {3.8460473117681427`*^9, 
   3.846047363168082*^9}, 3.8460548748927283`*^9, {3.846055491196979*^9, 
   3.8460554918520164`*^9}, 3.846055670752249*^9, {3.8460557995676165`*^9, 
   3.8460559448719273`*^9}, {3.846055980621972*^9, 3.8460560004461064`*^9}, {
   3.846056615459283*^9, 3.846056616928367*^9}, {3.8460567133538823`*^9, 
   3.8460567306258707`*^9}, {3.8460567766415024`*^9, 
   3.8460568307215953`*^9}, {3.846059396201332*^9, 3.8460594334794645`*^9}, {
   3.846061135315804*^9, 3.8460611980113897`*^9}, {3.8460614257734175`*^9, 
   3.8460614334828587`*^9}, {3.8463168230665016`*^9, 3.846316901224972*^9}, {
   3.846316960777378*^9, 3.8463170807182384`*^9}, {3.8463171109909697`*^9, 
   3.8463171577506447`*^9}, {3.846317440804834*^9, 3.846317466737317*^9}, {
   3.8463176324507957`*^9, 3.8463177293593383`*^9}, {3.8463177643593407`*^9, 
   3.8463177833834286`*^9}, {3.846317817487379*^9, 3.846317834719365*^9}, {
   3.8463185646181126`*^9, 3.8463185751447144`*^9}, {3.846318633089029*^9, 
   3.846318664655834*^9}, {3.846318722191125*^9, 3.846318828437202*^9}, {
   3.846319009237543*^9, 3.846319220994655*^9}, {3.8463193812168193`*^9, 
   3.8463193867931385`*^9}, {3.846319427946492*^9, 3.8463194326017585`*^9}, {
   3.8463194753382025`*^9, 3.8463194924721828`*^9}, {3.846596301541171*^9, 
   3.8465963032132673`*^9}, {3.8465966430657053`*^9, 3.846596645880866*^9}, {
   3.846658868628804*^9, 3.8466589857065005`*^9}, {3.8466590220275784`*^9, 
   3.8466590419377165`*^9}, {3.846682006017187*^9, 3.8466820206950264`*^9}, {
   3.8466856361268177`*^9, 3.846685849016994*^9}, {3.846685938322102*^9, 
   3.846685961905451*^9}, {3.8466860035048304`*^9, 3.846686041191986*^9}, {
   3.8466861184644055`*^9, 3.8466861666471615`*^9}, {3.8466863010798507`*^9, 
   3.8466863457344046`*^9}, {3.8788320770310774`*^9, 3.878832176288107*^9}, {
   3.8788329961247263`*^9, 3.878833008537199*^9}, {3.8788347802415104`*^9, 
   3.878834847371442*^9}, {3.878834881382534*^9, 3.87883499894761*^9}},
 CellLabel->
  "In[144]:=",ExpressionUUID->"2b1bc1c3-2be8-4ef1-a047-d9ab0b59d753"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      RasterBox[SparseArray[
       Automatic, {10, 10}, 1., {
        1, {{0, 2, 5, 5, 9, 10, 10, 13, 14, 15, 20}, {{1}, {7}, {2}, {4}, {
          5}, {2}, {4}, {6}, {7}, {2}, {4}, {5}, {10}, {6}, {6}, {1}, {3}, {
          5}, {8}, {10}}}, {0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 
         0., 0., 0., 0., 0., 0., 0., 0.}}], {{0, 0}, {10, 10}}, {0, 1}],
      DisplayFunction->Identity,
      Frame->Automatic,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.4999999999999991, 0.5}, {0.5, 15.900000000000034`}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultPlotStyle" -> Automatic},
      PlotLabel->FormBox[
        TemplateBox[{"\"p = \"", "0.2`"}, "RowDefault"], TraditionalForm]], {195., -189.},
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[
      RasterBox[SparseArray[
       Automatic, {10, 10}, 1., {
        1, {{0, 5, 7, 10, 11, 14, 19, 24, 28, 32, 37}, {{1}, {5}, {6}, {7}, {
          9}, {3}, {10}, {1}, {5}, {8}, {1}, {4}, {7}, {9}, {1}, {2}, {7}, {
          8}, {9}, {2}, {3}, {7}, {8}, {10}, {2}, {5}, {7}, {8}, {3}, {4}, {
          8}, {9}, {1}, {3}, {6}, {7}, {9}}}, {0., 0., 0., 0., 0., 0., 0., 0.,
          0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 
         0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.}}], {{0, 0}, {10, 
       10}}, {0, 1}],
      DisplayFunction->Identity,
      Frame->Automatic,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.4999999999999991, 0.5}, {0.5, 15.900000000000034`}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultPlotStyle" -> Automatic},
      PlotLabel->FormBox[
        TemplateBox[{"\"p = \"", "0.4`"}, "RowDefault"], TraditionalForm]], {585., -189.},
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[
      RasterBox[SparseArray[
       Automatic, {10, 10}, 1., {
        1, {{0, 6, 10, 17, 24, 29, 33, 42, 47, 50, 55}, {{1}, {3}, {4}, {7}, {
          8}, {9}, {1}, {6}, {8}, {10}, {1}, {3}, {4}, {6}, {8}, {9}, {10}, {
          2}, {3}, {4}, {5}, {6}, {9}, {10}, {3}, {4}, {7}, {9}, {10}, {1}, {
          3}, {5}, {8}, {1}, {2}, {3}, {5}, {6}, {7}, {8}, {9}, {10}, {1}, {
          2}, {7}, {8}, {10}, {2}, {5}, {7}, {2}, {4}, {5}, {7}, {
          9}}}, CompressedData["
1:eJxTTMoPSmVkYGAwZxgFQxUAAE9ZAeI=
         "]}], {{0, 0}, {10, 10}}, {0, 1}],
      DisplayFunction->Identity,
      Frame->Automatic,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.4999999999999991, 0.5}, {0.5, 15.900000000000034`}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultPlotStyle" -> Automatic},
      PlotLabel->FormBox[
        TemplateBox[{"\"p = \"", "0.6000000000000001`"}, "RowDefault"], 
        TraditionalForm]], {975., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[
      RasterBox[SparseArray[
       Automatic, {10, 10}, 1., {
        1, {{0, 9, 17, 26, 34, 40, 47, 56, 66, 75, 84}, {{1}, {2}, {3}, {4}, {
          5}, {6}, {7}, {8}, {9}, {1}, {2}, {4}, {5}, {6}, {7}, {8}, {9}, {
          1}, {2}, {3}, {4}, {6}, {7}, {8}, {9}, {10}, {2}, {3}, {5}, {6}, {
          7}, {8}, {9}, {10}, {1}, {4}, {5}, {6}, {8}, {10}, {2}, {4}, {5}, {
          6}, {7}, {9}, {10}, {1}, {2}, {4}, {5}, {6}, {7}, {8}, {9}, {10}, {
          1}, {2}, {3}, {4}, {5}, {6}, {7}, {8}, {9}, {10}, {1}, {3}, {4}, {
          5}, {6}, {7}, {8}, {9}, {10}, {1}, {2}, {3}, {4}, {5}, {6}, {7}, {
          8}, {10}}}, CompressedData["
1:eJxTTMoPSmVkYGAIYRgFo2BwAwBQ2wH/
         "]}], {{0, 0}, {10, 10}}, {0, 1}],
      DisplayFunction->Identity,
      Frame->Automatic,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.4999999999999991, 0.5}, {0.5, 15.900000000000034`}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultPlotStyle" -> Automatic},
      PlotLabel->FormBox[
        TemplateBox[{"\"p = \"", "0.8`"}, "RowDefault"], TraditionalForm]], {1365., -189.},
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDggmIQexSMglEwCkbBKBgFo2AUUBcAAK6cAcQ=
       "], {{0, 0}, {10, 10}}, {0, 1}],
      DisplayFunction->Identity,
      Frame->Automatic,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.4999999999999991, 0.5}, {0.5, 15.900000000000034`}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultPlotStyle" -> Automatic},
      PlotLabel->FormBox[
        TemplateBox[{"\"p = \"", "1.`"}, "RowDefault"], TraditionalForm]], {1755., -189.},
      ImageScaled[{0.5, 0.5}], {360., 360.}]}, {}},
  ImageSize->Full,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.8466859252493544`*^9, 3.8466859626884956`*^9}, 
   3.8466860122143283`*^9, 3.8466861767747407`*^9, 3.84668622135229*^9, {
   3.8466863019709015`*^9, 3.846686315744689*^9}, 3.846686346214432*^9, 
   3.8788315228415995`*^9, 3.8788316248907275`*^9, 3.878831877595063*^9, 
   3.8788320836857023`*^9, {3.878832142463879*^9, 3.8788321773147683`*^9}, 
   3.8788322735931487`*^9, 3.8788324071887927`*^9, {3.878832974004711*^9, 
   3.878833013337411*^9}, 3.878833060917334*^9, 3.8788331902701735`*^9, 
   3.8788347357408867`*^9, 3.878834799007399*^9, {3.878834907998164*^9, 
   3.8788349146378007`*^9}, {3.8788349737110047`*^9, 3.8788350474956474`*^9}},
 CellLabel->
  "Out[150]=",ExpressionUUID->"856d1b9b-636c-42cd-9570-be29a465d2a5"],

Cell[BoxData["\<\"Hoshen-Kopelman labbeling:\"\>"], "Print",
 CellChangeTimes->{
  3.846686176781741*^9, 3.8466862213582907`*^9, {3.846686301976902*^9, 
   3.8466863157506895`*^9}, 3.8466863462204323`*^9, 3.8788315228505363`*^9, 
   3.878831624248316*^9, 3.8788318769603124`*^9, 3.878832082964712*^9, {
   3.8788321421736684`*^9, 3.878832177041507*^9}, 3.87883227324981*^9, 
   3.8788324067954535`*^9, {3.8788329737531595`*^9, 3.87883301334735*^9}, 
   3.878833060926309*^9, 3.8788331902811823`*^9, 3.8788347357408867`*^9, 
   3.8788347990140944`*^9, {3.8788349085470443`*^9, 3.8788349151814485`*^9}, {
   3.8788349742424784`*^9, 3.8788350475047364`*^9}},
 CellLabel->
  "During evaluation of \
In[144]:=",ExpressionUUID->"03d56af1-1d43-4668-b97c-5cf18dd2d487"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "2", "0", "3", "0", "0", "4", "0", "5"},
       {"0", "0", "0", "0", "0", "6", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "6", "0", "0", "0", "0"},
       {"0", "0", "0", "7", "7", "0", "0", "0", "0", "8"},
       {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
       {"0", "9", "0", "0", "0", "0", "0", "0", "0", "0"},
       {"0", "9", "0", "10", "0", "11", "11", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
       {"0", "12", "0", "13", "13", "0", "0", "0", "0", "0"},
       {"14", "0", "0", "0", "0", "0", "15", "0", "0", "0"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "2", "0", "0", "3", "3", "0", "4", "0"},
       {"0", "0", "2", "2", "0", "0", "0", "4", "4", "0"},
       {"0", "5", "0", "0", "6", "0", "4", "4", "0", "0"},
       {"0", "5", "5", "0", "0", "0", "4", "4", "0", "7"},
       {"5", "5", "0", "0", "0", "0", "4", "4", "4", "0"},
       {"0", "0", "0", "8", "0", "0", "4", "0", "4", "0"},
       {"9", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
       {"9", "0", "0", "0", "10", "0", "0", "11", "0", "0"},
       {"0", "0", "12", "0", "0", "0", "0", "0", "0", "13"},
       {"14", "0", "0", "0", "15", "15", "15", "0", "16", "0"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "1", "0", "2", "2", "0", "3", "0", "4", "0"},
       {"0", "1", "0", "0", "2", "0", "3", "0", "0", "0"},
       {"1", "1", "0", "0", "0", "0", "3", "3", "0", "3"},
       {"1", "1", "1", "0", "3", "3", "3", "3", "3", "3"},
       {"1", "0", "1", "0", "3", "0", "0", "3", "0", "0"},
       {"0", "0", "1", "1", "0", "0", "5", "0", "6", "6"},
       {"0", "1", "1", "1", "1", "1", "0", "0", "6", "6"},
       {"7", "0", "1", "1", "0", "1", "0", "6", "6", "6"},
       {"7", "0", "0", "0", "0", "1", "0", "6", "0", "6"},
       {"7", "0", "8", "8", "0", "0", "6", "6", "6", "0"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "1", "1", "1", "1", "1", "1", "1", "0", "1"},
       {"1", "0", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "0", "1", "1", "1", "1", "1", "1", "1"},
       {"0", "1", "0", "1", "1", "1", "1", "0", "1", "1"},
       {"2", "0", "0", "1", "1", "1", "0", "1", "0", "1"},
       {"0", "1", "1", "0", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "0", "1", "1", "1", "1", "1"},
       {"1", "1", "0", "1", "1", "1", "1", "1", "1", "0"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "0"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
       {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.8466859252493544`*^9, 3.8466859626884956`*^9}, 
   3.8466860122143283`*^9, 3.8466861767747407`*^9, 3.84668622135229*^9, {
   3.8466863019709015`*^9, 3.846686315744689*^9}, 3.846686346214432*^9, 
   3.8788315228415995`*^9, 3.8788316248907275`*^9, 3.878831877595063*^9, 
   3.8788320836857023`*^9, {3.878832142463879*^9, 3.8788321773147683`*^9}, 
   3.8788322735931487`*^9, 3.8788324071887927`*^9, {3.878832974004711*^9, 
   3.878833013337411*^9}, 3.878833060917334*^9, 3.8788331902701735`*^9, 
   3.8788347357408867`*^9, 3.878834799007399*^9, {3.878834907998164*^9, 
   3.8788349146378007`*^9}, {3.8788349737110047`*^9, 3.87883504751569*^9}},
 CellLabel->
  "Out[152]=",ExpressionUUID->"c0261423-53a2-4a40-8cb8-470d6397cae1"],

Cell[BoxData["\<\"Sizes of clusters:\"\>"], "Print",
 CellChangeTimes->{
  3.846686176781741*^9, 3.8466862213582907`*^9, {3.846686301976902*^9, 
   3.8466863157506895`*^9}, 3.8466863462204323`*^9, 3.8788315228505363`*^9, 
   3.878831624248316*^9, 3.8788318769603124`*^9, 3.878832082964712*^9, {
   3.8788321421736684`*^9, 3.878832177041507*^9}, 3.87883227324981*^9, 
   3.8788324067954535`*^9, {3.8788329737531595`*^9, 3.87883301334735*^9}, 
   3.878833060926309*^9, 3.8788331902811823`*^9, 3.8788347357408867`*^9, 
   3.8788347990140944`*^9, {3.8788349085470443`*^9, 3.8788349151814485`*^9}, {
   3.8788349742424784`*^9, 3.87883504751569*^9}},
 CellLabel->
  "During evaluation of \
In[144]:=",ExpressionUUID->"600d6508-d379-4cb0-8a31-2425310d9067"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2", ",", "1",
      ",", "2", ",", "1", ",", "2", ",", "1", ",", "2", ",", "1", ",", "1"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "3", ",", "2", ",", "12", ",", "5", ",", "1", ",", "1", ",", 
     "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
     "3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "20", ",", "3", ",", "13", ",", "1", ",", "1", ",", "12", ",", "3", ",", 
     "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"83", ",", "1"}], "}"}], ",", 
   RowBox[{"{", "100", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8466859252493544`*^9, 3.8466859626884956`*^9}, 
   3.8466860122143283`*^9, 3.8466861767747407`*^9, 3.84668622135229*^9, {
   3.8466863019709015`*^9, 3.846686315744689*^9}, 3.846686346214432*^9, 
   3.8788315228415995`*^9, 3.8788316248907275`*^9, 3.878831877595063*^9, 
   3.8788320836857023`*^9, {3.878832142463879*^9, 3.8788321773147683`*^9}, 
   3.8788322735931487`*^9, 3.8788324071887927`*^9, {3.878832974004711*^9, 
   3.878833013337411*^9}, 3.878833060917334*^9, 3.8788331902701735`*^9, 
   3.8788347357408867`*^9, 3.878834799007399*^9, {3.878834907998164*^9, 
   3.8788349146378007`*^9}, {3.8788349737110047`*^9, 3.878835047520734*^9}},
 CellLabel->
  "Out[154]=",ExpressionUUID->"5a3096be-7bc8-420e-9e22-8c5271595f7b"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1428., 861.75},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (December 12, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"52c1897a-bf60-45fe-b4ac-1c5a82e76624"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 296, 6, 34, "Text",ExpressionUUID->"09352dc8-3374-4919-9ad3-bb9e0f6dc757"],
Cell[844, 28, 219, 4, 28, "Input",ExpressionUUID->"b34912b4-662f-4368-b306-2abe0c3985e9"],
Cell[CellGroupData[{
Cell[1088, 36, 492, 7, 66, "Section",ExpressionUUID->"9c44156e-68a8-492f-9a16-76a98c8aa6ef"],
Cell[1583, 45, 927, 15, 34, "Text",ExpressionUUID->"b779bbf7-cc84-460c-a7a6-bfc985e7489c"],
Cell[2513, 62, 18079, 367, 1322, "Input",ExpressionUUID->"b9fad58f-0cc3-4473-9260-59bcf8d45ece"],
Cell[20595, 431, 901, 15, 34, "Text",ExpressionUUID->"0fff6592-5b78-4c23-86c5-693acd583b81"],
Cell[21499, 448, 2931, 65, 254, "Input",ExpressionUUID->"a8a5d70e-c070-42dd-a69f-da97f512ea31"],
Cell[24433, 515, 214, 5, 34, "Text",ExpressionUUID->"50560771-1f87-43ae-9abb-b0020376c1ac"],
Cell[CellGroupData[{
Cell[24672, 524, 9590, 187, 291, "Input",ExpressionUUID->"2b1bc1c3-2be8-4ef1-a047-d9ab0b59d753"],
Cell[34265, 713, 7791, 159, 281, "Output",ExpressionUUID->"856d1b9b-636c-42cd-9570-be29a465d2a5"],
Cell[42059, 874, 761, 12, 22, "Print",ExpressionUUID->"03d56af1-1d43-4668-b97c-5cf18dd2d487"],
Cell[42823, 888, 6047, 128, 185, "Output",ExpressionUUID->"c0261423-53a2-4a40-8cb8-470d6397cae1"],
Cell[48873, 1018, 750, 12, 22, "Print",ExpressionUUID->"600d6508-d379-4cb0-8a31-2425310d9067"],
Cell[49626, 1032, 1452, 30, 32, "Output",ExpressionUUID->"5a3096be-7bc8-420e-9e22-8c5271595f7b"]
}, Open  ]]
}, Open  ]]
}
]
*)

